package linguist

var (
	Languages = map[string]*Language{
		"ABAP": &Language{
			Name:       "ABAP",
			Type:       "programming",
			Color:      "#E8274B",
			Extensions: []string{".abap"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"AGS Script": &Language{
			Name:       "AGS Script",
			Type:       "programming",
			Color:      "#B9D9FF",
			Aliases:    []string{"ags"},
			Extensions: []string{".asc", ".ash"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"AMPL": &Language{
			Name:       "AMPL",
			Type:       "programming",
			Color:      "#E6EFBB",
			Extensions: []string{".ampl", ".mod"},
			TmScope:    "source.ampl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ANTLR": &Language{
			Name:       "ANTLR",
			Type:       "programming",
			Color:      "#9DC3FF",
			Extensions: []string{".g4"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"API Blueprint": &Language{
			Name:       "API Blueprint",
			Type:       "markup",
			Color:      "#2ACCA8",
			Extensions: []string{".apib"},
			TmScope:    "text.html.markdown.source.gfm.apib",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"APL": &Language{
			Name:       "APL",
			Type:       "programming",
			Color:      "#5A8164",
			Extensions: []string{".apl", ".dyalog"},
			TmScope:    "source.apl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ASP": &Language{
			Name:       "ASP",
			Type:       "programming",
			Color:      "#6a40fd",
			Aliases:    []string{"aspx", "aspx-vb"},
			Extensions: []string{".asp", ".asax", ".ascx", ".ashx", ".asmx", ".aspx", ".axd"},
			TmScope:    "text.html.asp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ATS": &Language{
			Name:       "ATS",
			Type:       "programming",
			Color:      "#1ac620",
			Aliases:    []string{"ats2"},
			Extensions: []string{".dats", ".hats", ".sats"},
			TmScope:    "source.ats",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ActionScript": &Language{
			Name:       "ActionScript",
			Type:       "programming",
			Color:      "#882B0F",
			Aliases:    []string{"actionscript 3", "actionscript3", "as3"},
			Extensions: []string{".as"},
			TmScope:    "source.actionscript.3",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ada": &Language{
			Name:       "Ada",
			Type:       "programming",
			Color:      "#02f88c",
			Aliases:    []string{"ada95", "ada2005"},
			Extensions: []string{".adb", ".ada", ".ads"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Agda": &Language{
			Name:       "Agda",
			Type:       "programming",
			Color:      "#315665",
			Extensions: []string{".agda"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Alloy": &Language{
			Name:       "Alloy",
			Type:       "programming",
			Color:      "#64C800",
			Extensions: []string{".als"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ant Build System": &Language{
			Name:       "Ant Build System",
			Type:       "data",
			Filenames:  []string{"ant.xml", "build.xml"},
			TmScope:    "text.xml.ant",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"ApacheConf": &Language{
			Name:       "ApacheConf",
			Type:       "markup",
			Aliases:    []string{"aconf", "apache"},
			Extensions: []string{".apacheconf", ".vhost"},
			TmScope:    "source.apache-config",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Apex": &Language{
			Name:       "Apex",
			Type:       "programming",
			Extensions: []string{".cls"},
			TmScope:    "source.java",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"AppleScript": &Language{
			Name:         "AppleScript",
			Type:         "programming",
			Color:        "#101F1F",
			Aliases:      []string{"osascript"},
			Extensions:   []string{".applescript", ".scpt"},
			Interpreters: []string{"osascript"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Arc": &Language{
			Name:       "Arc",
			Type:       "programming",
			Color:      "#aa2afe",
			Extensions: []string{".arc"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Arduino": &Language{
			Name:       "Arduino",
			Type:       "programming",
			Color:      "#bd79d1",
			Extensions: []string{".ino"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"AsciiDoc": &Language{
			Name:       "AsciiDoc",
			Type:       "prose",
			Extensions: []string{".asciidoc", ".adoc", ".asc"},
			TmScope:    "text.html.asciidoc",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"AspectJ": &Language{
			Name:       "AspectJ",
			Type:       "programming",
			Color:      "#a957b0",
			Extensions: []string{".aj"},
			TmScope:    "source.aspectj",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Assembly": &Language{
			Name:       "Assembly",
			Type:       "programming",
			Color:      "#6E4C13",
			Aliases:    []string{"nasm"},
			Extensions: []string{".asm", ".a51", ".inc", ".nasm"},
			TmScope:    "source.asm.x86",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Augeas": &Language{
			Name:       "Augeas",
			Type:       "programming",
			Extensions: []string{".aug"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"AutoHotkey": &Language{
			Name:       "AutoHotkey",
			Type:       "programming",
			Color:      "#6594b9",
			Aliases:    []string{"ahk"},
			Extensions: []string{".ahk", ".ahkl"},
			TmScope:    "source.ahk",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"AutoIt": &Language{
			Name:       "AutoIt",
			Type:       "programming",
			Color:      "#1C3552",
			Aliases:    []string{"au3", "AutoIt3", "AutoItScript"},
			Extensions: []string{".au3"},
			TmScope:    "source.autoit.3",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Awk": &Language{
			Name:         "Awk",
			Type:         "programming",
			Extensions:   []string{".awk", ".auk", ".gawk", ".mawk", ".nawk"},
			Interpreters: []string{"awk", "gawk", "mawk", "nawk"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Batchfile": &Language{
			Name:       "Batchfile",
			Type:       "programming",
			Color:      "#C1F12E",
			Aliases:    []string{"bat", "batch", "dosbatch", "winbatch"},
			Extensions: []string{".bat", ".cmd"},
			TmScope:    "source.dosbatch",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Befunge": &Language{
			Name:       "Befunge",
			Type:       "programming",
			Extensions: []string{".befunge"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Bison": &Language{
			Name:       "Bison",
			Type:       "programming",
			Group:      "Yacc",
			Color:      "#6A463F",
			Extensions: []string{".bison"},
			TmScope:    "source.bison",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"BitBake": &Language{
			Name:       "BitBake",
			Type:       "programming",
			Extensions: []string{".bb"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"BlitzBasic": &Language{
			Name:       "BlitzBasic",
			Type:       "programming",
			Aliases:    []string{"b3d", "blitz3d", "blitzplus", "bplus"},
			Extensions: []string{".bb", ".decls"},
			TmScope:    "source.blitzmax",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"BlitzMax": &Language{
			Name:       "BlitzMax",
			Type:       "programming",
			Color:      "#cd6400",
			Aliases:    []string{"bmax"},
			Extensions: []string{".bmx"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Bluespec": &Language{
			Name:       "Bluespec",
			Type:       "programming",
			Extensions: []string{".bsv"},
			TmScope:    "source.bsv",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Boo": &Language{
			Name:       "Boo",
			Type:       "programming",
			Color:      "#d4bec1",
			Extensions: []string{".boo"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Brainfuck": &Language{
			Name:       "Brainfuck",
			Type:       "programming",
			Color:      "#2F2530",
			Extensions: []string{".b", ".bf"},
			TmScope:    "source.bf",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Brightscript": &Language{
			Name:       "Brightscript",
			Type:       "programming",
			Extensions: []string{".brs"},
			TmScope:    "source.brightscript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Bro": &Language{
			Name:       "Bro",
			Type:       "programming",
			Extensions: []string{".bro"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"C": &Language{
			Name:         "C",
			Type:         "programming",
			Color:        "#555555",
			Extensions:   []string{".c", ".cats", ".h", ".idc", ".w"},
			Interpreters: []string{"tcc"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"C#": &Language{
			Name:       "C#",
			Type:       "programming",
			Color:      "#178600",
			Aliases:    []string{"csharp"},
			Extensions: []string{".cs", ".cake", ".cshtml", ".csx"},
			TmScope:    "source.cs",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"C++": &Language{
			Name:       "C++",
			Type:       "programming",
			Color:      "#f34b7d",
			Aliases:    []string{"cpp"},
			Extensions: []string{".cpp", ".c++", ".cc", ".cp", ".cxx", ".h", ".h++", ".hh", ".hpp", ".hxx", ".inc", ".inl", ".ipp", ".tcc", ".tpp"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"C-ObjDump": &Language{
			Name:       "C-ObjDump",
			Type:       "data",
			Extensions: []string{".c-objdump"},
			TmScope:    "objdump.x86asm",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"C2hs Haskell": &Language{
			Name:       "C2hs Haskell",
			Type:       "programming",
			Group:      "Haskell",
			Aliases:    []string{"c2hs"},
			Extensions: []string{".chs"},
			TmScope:    "source.haskell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"CLIPS": &Language{
			Name:       "CLIPS",
			Type:       "programming",
			Extensions: []string{".clp"},
			TmScope:    "source.clips",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"CMake": &Language{
			Name:       "CMake",
			Type:       "programming",
			Extensions: []string{".cmake", ".cmake.in"},
			Filenames:  []string{"CMakeLists.txt"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"COBOL": &Language{
			Name:       "COBOL",
			Type:       "programming",
			Extensions: []string{".cob", ".cbl", ".ccp", ".cobol", ".cpy"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"CSS": &Language{
			Name:       "CSS",
			Type:       "markup",
			Color:      "#563d7c",
			Extensions: []string{".css"},
			TmScope:    "source.css",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"CSV": &Language{
			Name:       "CSV",
			Type:       "data",
			Extensions: []string{".csv"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Cap'n Proto": &Language{
			Name:       "Cap'n Proto",
			Type:       "programming",
			Extensions: []string{".capnp"},
			TmScope:    "source.capnp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"CartoCSS": &Language{
			Name:       "CartoCSS",
			Type:       "programming",
			Aliases:    []string{"Carto"},
			Extensions: []string{".mss"},
			TmScope:    "source.css.mss",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ceylon": &Language{
			Name:       "Ceylon",
			Type:       "programming",
			Extensions: []string{".ceylon"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Chapel": &Language{
			Name:       "Chapel",
			Type:       "programming",
			Color:      "#8dc63f",
			Aliases:    []string{"chpl"},
			Extensions: []string{".chpl"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Charity": &Language{
			Name:       "Charity",
			Type:       "programming",
			Extensions: []string{".ch"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ChucK": &Language{
			Name:       "ChucK",
			Type:       "programming",
			Extensions: []string{".ck"},
			TmScope:    "source.java",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Cirru": &Language{
			Name:       "Cirru",
			Type:       "programming",
			Color:      "#ccccff",
			Extensions: []string{".cirru"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Clarion": &Language{
			Name:       "Clarion",
			Type:       "programming",
			Color:      "#db901e",
			Extensions: []string{".clw"},
			TmScope:    "source.clarion",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Clean": &Language{
			Name:       "Clean",
			Type:       "programming",
			Color:      "#3F85AF",
			Extensions: []string{".icl", ".dcl"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Click": &Language{
			Name:       "Click",
			Type:       "programming",
			Color:      "#E4E6F3",
			Extensions: []string{".click"},
			TmScope:    "source.click",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Clojure": &Language{
			Name:       "Clojure",
			Type:       "programming",
			Color:      "#db5855",
			Extensions: []string{".clj", ".boot", ".cl2", ".cljc", ".cljs", ".cljs.hl", ".cljscm", ".cljx", ".hic"},
			Filenames:  []string{"riemann.config"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"CoffeeScript": &Language{
			Name:         "CoffeeScript",
			Type:         "programming",
			Color:        "#244776",
			Aliases:      []string{"coffee", "coffee-script"},
			Extensions:   []string{".coffee", "._coffee", ".cake", ".cjsx", ".cson", ".iced"},
			Filenames:    []string{"Cakefile"},
			Interpreters: []string{"coffee"},
			TmScope:      "source.coffee",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"ColdFusion": &Language{
			Name:       "ColdFusion",
			Type:       "programming",
			Group:      "ColdFusion",
			Color:      "#ed2cd6",
			Aliases:    []string{"cfm", "cfml", "coldfusion html"},
			Extensions: []string{".cfm", ".cfml"},
			TmScope:    "text.html.cfm",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ColdFusion CFC": &Language{
			Name:       "ColdFusion CFC",
			Type:       "programming",
			Group:      "ColdFusion",
			Color:      "#ed2cd6",
			Aliases:    []string{"cfc"},
			Extensions: []string{".cfc"},
			TmScope:    "source.cfscript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Common Lisp": &Language{
			Name:         "Common Lisp",
			Type:         "programming",
			Color:        "#3fb68b",
			Aliases:      []string{"lisp"},
			Extensions:   []string{".lisp", ".asd", ".cl", ".l", ".lsp", ".ny", ".podsl", ".sexp"},
			Interpreters: []string{"lisp", "sbcl", "ccl", "clisp", "ecl"},
			TmScope:      "source.lisp",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Component Pascal": &Language{
			Name:       "Component Pascal",
			Type:       "programming",
			Color:      "#B0CE4E",
			Aliases:    []string{"delphi", "objectpascal"},
			Extensions: []string{".cp", ".cps"},
			TmScope:    "source.pascal",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Cool": &Language{
			Name:       "Cool",
			Type:       "programming",
			Extensions: []string{".cl"},
			TmScope:    "source.cool",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Coq": &Language{
			Name:       "Coq",
			Type:       "programming",
			Extensions: []string{".coq", ".v"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Cpp-ObjDump": &Language{
			Name:       "Cpp-ObjDump",
			Type:       "data",
			Aliases:    []string{"c++-objdumb"},
			Extensions: []string{".cppobjdump", ".c++-objdump", ".c++objdump", ".cpp-objdump", ".cxx-objdump"},
			TmScope:    "objdump.x86asm",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Creole": &Language{
			Name:       "Creole",
			Type:       "prose",
			Extensions: []string{".creole"},
			TmScope:    "text.html.creole",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Crystal": &Language{
			Name:         "Crystal",
			Type:         "programming",
			Color:        "#776791",
			Extensions:   []string{".cr"},
			Interpreters: []string{"crystal"},
			TmScope:      "source.crystal",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Cucumber": &Language{
			Name:       "Cucumber",
			Type:       "programming",
			Color:      "#5B2063",
			Aliases:    []string{"gherkin"},
			Extensions: []string{".feature"},
			TmScope:    "text.gherkin.feature",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Cuda": &Language{
			Name:       "Cuda",
			Type:       "programming",
			Color:      "#3A4E3A",
			Extensions: []string{".cu", ".cuh"},
			TmScope:    "source.cuda-c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Cycript": &Language{
			Name:       "Cycript",
			Type:       "programming",
			Extensions: []string{".cy"},
			TmScope:    "source.js",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Cython": &Language{
			Name:       "Cython",
			Type:       "programming",
			Group:      "Python",
			Aliases:    []string{"pyrex"},
			Extensions: []string{".pyx", ".pxd", ".pxi"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"D": &Language{
			Name:       "D",
			Type:       "programming",
			Color:      "#ba595e",
			Extensions: []string{".d", ".di"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"D-ObjDump": &Language{
			Name:       "D-ObjDump",
			Type:       "data",
			Extensions: []string{".d-objdump"},
			TmScope:    "objdump.x86asm",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"DIGITAL Command Language": &Language{
			Name:       "DIGITAL Command Language",
			Type:       "programming",
			Aliases:    []string{"dcl"},
			Extensions: []string{".com"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"DM": &Language{
			Name:       "DM",
			Type:       "programming",
			Color:      "#447265",
			Aliases:    []string{"byond"},
			Extensions: []string{".dm"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"DNS Zone": &Language{
			Name:       "DNS Zone",
			Type:       "data",
			Extensions: []string{".zone", ".arpa"},
			TmScope:    "text.zone_file",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"DTrace": &Language{
			Name:         "DTrace",
			Type:         "programming",
			Aliases:      []string{"dtrace-script"},
			Extensions:   []string{".d"},
			Interpreters: []string{"dtrace"},
			TmScope:      "source.c",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Darcs Patch": &Language{
			Name:       "Darcs Patch",
			Type:       "data",
			Aliases:    []string{"dpatch"},
			Extensions: []string{".darcspatch", ".dpatch"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Dart": &Language{
			Name:       "Dart",
			Type:       "programming",
			Color:      "#00B4AB",
			Extensions: []string{".dart"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Diff": &Language{
			Name:       "Diff",
			Type:       "data",
			Aliases:    []string{"udiff"},
			Extensions: []string{".diff", ".patch"},
			TmScope:    "source.diff",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Dockerfile": &Language{
			Name:       "Dockerfile",
			Type:       "data",
			Extensions: []string{".dockerfile"},
			Filenames:  []string{"Dockerfile"},
			TmScope:    "source.dockerfile",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Dogescript": &Language{
			Name:       "Dogescript",
			Type:       "programming",
			Color:      "#cca760",
			Extensions: []string{".djs"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Dylan": &Language{
			Name:       "Dylan",
			Type:       "programming",
			Color:      "#6c616e",
			Extensions: []string{".dylan", ".dyl", ".intr", ".lid"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"E": &Language{
			Name:       "E",
			Type:       "programming",
			Color:      "#ccce35",
			Extensions: []string{".E"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ECL": &Language{
			Name:       "ECL",
			Type:       "programming",
			Color:      "#8a1267",
			Extensions: []string{".ecl", ".eclxml"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ECLiPSe": &Language{
			Name:       "ECLiPSe",
			Type:       "programming",
			Group:      "prolog",
			Extensions: []string{".ecl"},
			TmScope:    "source.prolog.eclipse",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Eagle": &Language{
			Name:       "Eagle",
			Type:       "markup",
			Color:      "#814C05",
			Extensions: []string{".sch", ".brd"},
			TmScope:    "text.xml",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Ecere Projects": &Language{
			Name:       "Ecere Projects",
			Type:       "data",
			Group:      "JavaScript",
			Extensions: []string{".epj"},
			TmScope:    "source.json",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Eiffel": &Language{
			Name:       "Eiffel",
			Type:       "programming",
			Color:      "#946d57",
			Extensions: []string{".e"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Elixir": &Language{
			Name:         "Elixir",
			Type:         "programming",
			Color:        "#6e4a7e",
			Extensions:   []string{".ex", ".exs"},
			Filenames:    []string{"mix.lock"},
			Interpreters: []string{"elixir"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Elm": &Language{
			Name:       "Elm",
			Type:       "programming",
			Color:      "#60B5CC",
			Extensions: []string{".elm"},
			TmScope:    "source.elm",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Emacs Lisp": &Language{
			Name:       "Emacs Lisp",
			Type:       "programming",
			Color:      "#c065db",
			Aliases:    []string{"elisp", "emacs"},
			Extensions: []string{".el", ".emacs", ".emacs.desktop"},
			Filenames:  []string{".emacs", ".emacs.desktop"},
			TmScope:    "source.lisp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"EmberScript": &Language{
			Name:       "EmberScript",
			Type:       "programming",
			Color:      "#FFF4F3",
			Extensions: []string{".em", ".emberscript"},
			TmScope:    "source.coffee",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Erlang": &Language{
			Name:         "Erlang",
			Type:         "programming",
			Color:        "#B83998",
			Extensions:   []string{".erl", ".es", ".escript", ".hrl", ".xrl", ".yrl"},
			Filenames:    []string{"rebar.config", "rebar.config.lock", "rebar.lock"},
			Interpreters: []string{"escript"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"F#": &Language{
			Name:       "F#",
			Type:       "programming",
			Color:      "#b845fc",
			Aliases:    []string{"fsharp"},
			Extensions: []string{".fs", ".fsi", ".fsx"},
			TmScope:    "source.fsharp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"FLUX": &Language{
			Name:       "FLUX",
			Type:       "programming",
			Color:      "#88ccff",
			Extensions: []string{".fx", ".flux"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"FORTRAN": &Language{
			Name:       "FORTRAN",
			Type:       "programming",
			Color:      "#4d41b1",
			Extensions: []string{".f90", ".f", ".f03", ".f08", ".f77", ".f95", ".for", ".fpp"},
			TmScope:    "source.fortran.modern",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Factor": &Language{
			Name:       "Factor",
			Type:       "programming",
			Color:      "#636746",
			Extensions: []string{".factor"},
			Filenames:  []string{".factor-boot-rc", ".factor-rc"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Fancy": &Language{
			Name:       "Fancy",
			Type:       "programming",
			Color:      "#7b9db4",
			Extensions: []string{".fy", ".fancypack"},
			Filenames:  []string{"Fakefile"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Fantom": &Language{
			Name:       "Fantom",
			Type:       "programming",
			Color:      "#dbded5",
			Extensions: []string{".fan"},
			TmScope:    "source.fan",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Filterscript": &Language{
			Name:       "Filterscript",
			Type:       "programming",
			Group:      "RenderScript",
			Extensions: []string{".fs"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Formatted": &Language{
			Name:       "Formatted",
			Type:       "data",
			Extensions: []string{".for", ".eam.fs"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Forth": &Language{
			Name:       "Forth",
			Type:       "programming",
			Color:      "#341708",
			Extensions: []string{".fth", ".4th", ".f", ".for", ".forth", ".fr", ".frt", ".fs"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"FreeMarker": &Language{
			Name:       "FreeMarker",
			Type:       "programming",
			Color:      "#0050b2",
			Aliases:    []string{"ftl"},
			Extensions: []string{".ftl"},
			TmScope:    "text.html.ftl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Frege": &Language{
			Name:       "Frege",
			Type:       "programming",
			Color:      "#00cafe",
			Extensions: []string{".fr"},
			TmScope:    "source.haskell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"G-code": &Language{
			Name:       "G-code",
			Type:       "data",
			Extensions: []string{".g", ".gco", ".gcode"},
			TmScope:    "source.gcode",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"GAMS": &Language{
			Name:       "GAMS",
			Type:       "programming",
			Extensions: []string{".gms"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"GAP": &Language{
			Name:       "GAP",
			Type:       "programming",
			Extensions: []string{".g", ".gap", ".gd", ".gi", ".tst"},
			TmScope:    "source.gap",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"GAS": &Language{
			Name:       "GAS",
			Type:       "programming",
			Group:      "Assembly",
			Extensions: []string{".s", ".ms"},
			TmScope:    "source.asm.x86",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"GDScript": &Language{
			Name:       "GDScript",
			Type:       "programming",
			Extensions: []string{".gd"},
			TmScope:    "source.gdscript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"GLSL": &Language{
			Name:       "GLSL",
			Type:       "programming",
			Extensions: []string{".glsl", ".fp", ".frag", ".frg", ".fs", ".fshader", ".geo", ".geom", ".glslv", ".gshader", ".shader", ".vert", ".vrx", ".vshader"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Game Maker Language": &Language{
			Name:       "Game Maker Language",
			Type:       "programming",
			Color:      "#8fb200",
			Extensions: []string{".gml"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Genshi": &Language{
			Name:       "Genshi",
			Type:       "programming",
			Aliases:    []string{"xml+genshi", "xml+kid"},
			Extensions: []string{".kid"},
			TmScope:    "text.xml.genshi",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Gentoo Ebuild": &Language{
			Name:       "Gentoo Ebuild",
			Type:       "programming",
			Group:      "Shell",
			Extensions: []string{".ebuild"},
			TmScope:    "source.shell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Gentoo Eclass": &Language{
			Name:       "Gentoo Eclass",
			Type:       "programming",
			Group:      "Shell",
			Extensions: []string{".eclass"},
			TmScope:    "source.shell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Gettext Catalog": &Language{
			Name:       "Gettext Catalog",
			Type:       "prose",
			Aliases:    []string{"pot"},
			Extensions: []string{".po", ".pot"},
			TmScope:    "source.po",
			AceMode:    "prose",
			Wrap:       false,
			Searchable: false,
		},
		"Glyph": &Language{
			Name:       "Glyph",
			Type:       "programming",
			Color:      "#e4cc98",
			Extensions: []string{".glf"},
			TmScope:    "source.tcl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Gnuplot": &Language{
			Name:         "Gnuplot",
			Type:         "programming",
			Color:        "#f0a9f0",
			Extensions:   []string{".gp", ".gnu", ".gnuplot", ".plot", ".plt"},
			Interpreters: []string{"gnuplot"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Go": &Language{
			Name:       "Go",
			Type:       "programming",
			Color:      "#375eab",
			Extensions: []string{".go"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Golo": &Language{
			Name:       "Golo",
			Type:       "programming",
			Color:      "#88562A",
			Extensions: []string{".golo"},
			TmScope:    "source.golo",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Gosu": &Language{
			Name:       "Gosu",
			Type:       "programming",
			Color:      "#82937f",
			Extensions: []string{".gs", ".gst", ".gsx", ".vark"},
			TmScope:    "source.gosu.2",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Grace": &Language{
			Name:       "Grace",
			Type:       "programming",
			Extensions: []string{".grace"},
			TmScope:    "source.grace",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Gradle": &Language{
			Name:       "Gradle",
			Type:       "data",
			Extensions: []string{".gradle"},
			TmScope:    "source.groovy.gradle",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Grammatical Framework": &Language{
			Name:       "Grammatical Framework",
			Type:       "programming",
			Color:      "#79aa7a",
			Aliases:    []string{"gf"},
			Extensions: []string{".gf"},
			TmScope:    "source.haskell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Graph Modeling Language": &Language{
			Name:       "Graph Modeling Language",
			Type:       "data",
			Extensions: []string{".gml"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Graphviz (DOT)": &Language{
			Name:       "Graphviz (DOT)",
			Type:       "data",
			Extensions: []string{".dot", ".gv"},
			TmScope:    "source.dot",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Groff": &Language{
			Name:       "Groff",
			Type:       "markup",
			Aliases:    []string{"nroff"},
			Extensions: []string{".man", ".1", ".1in", ".1m", ".1x", ".2", ".3", ".3in", ".3m", ".3qt", ".3x", ".4", ".5", ".6", ".7", ".8", ".9", ".l", ".ms", ".n", ".rno", ".roff"},
			TmScope:    "text.groff",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Groovy": &Language{
			Name:         "Groovy",
			Type:         "programming",
			Color:        "#e69f56",
			Extensions:   []string{".groovy", ".grt", ".gtpl", ".gvy"},
			Interpreters: []string{"groovy"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Groovy Server Pages": &Language{
			Name:       "Groovy Server Pages",
			Type:       "programming",
			Group:      "Groovy",
			Aliases:    []string{"gsp", "java server page"},
			Extensions: []string{".gsp"},
			TmScope:    "text.html.jsp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"HCL": &Language{
			Name:       "HCL",
			Type:       "programming",
			Extensions: []string{".hcl", ".tf"},
			TmScope:    "source.ruby",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"HTML": &Language{
			Name:       "HTML",
			Type:       "markup",
			Color:      "#e44b23",
			Aliases:    []string{"xhtml"},
			Extensions: []string{".html", ".htm", ".html.hl", ".inc", ".st", ".xht", ".xhtml"},
			TmScope:    "text.html.basic",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"HTML+Django": &Language{
			Name:       "HTML+Django",
			Type:       "markup",
			Group:      "HTML",
			Aliases:    []string{"django", "html+django/jinja", "html+jinja", "htmldjango"},
			Extensions: []string{".mustache", ".jinja"},
			TmScope:    "text.html.django",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"HTML+EEX": &Language{
			Name:       "HTML+EEX",
			Type:       "markup",
			Group:      "HTML",
			Aliases:    []string{"eex"},
			Extensions: []string{".eex"},
			TmScope:    "text.html.elixir",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"HTML+ERB": &Language{
			Name:       "HTML+ERB",
			Type:       "markup",
			Group:      "HTML",
			Aliases:    []string{"erb"},
			Extensions: []string{".erb", ".erb.deface"},
			TmScope:    "text.html.erb",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"HTML+PHP": &Language{
			Name:       "HTML+PHP",
			Type:       "markup",
			Group:      "HTML",
			Extensions: []string{".phtml"},
			TmScope:    "text.html.php",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"HTTP": &Language{
			Name:       "HTTP",
			Type:       "data",
			Extensions: []string{".http"},
			TmScope:    "source.httpspec",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Hack": &Language{
			Name:       "Hack",
			Type:       "programming",
			Color:      "#878787",
			Extensions: []string{".hh", ".php"},
			TmScope:    "text.html.php",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Haml": &Language{
			Name:       "Haml",
			Type:       "markup",
			Group:      "HTML",
			Color:      "#ECE2A9",
			Extensions: []string{".haml", ".haml.deface"},
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Handlebars": &Language{
			Name:       "Handlebars",
			Type:       "markup",
			Group:      "HTML",
			Color:      "#01a9d6",
			Aliases:    []string{"hbs", "htmlbars"},
			Extensions: []string{".handlebars", ".hbs"},
			TmScope:    "text.html.handlebars",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Harbour": &Language{
			Name:       "Harbour",
			Type:       "programming",
			Color:      "#0e60e3",
			Extensions: []string{".hb"},
			TmScope:    "source.harbour",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Haskell": &Language{
			Name:       "Haskell",
			Type:       "programming",
			Color:      "#29b544",
			Extensions: []string{".hs", ".hsc"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Haxe": &Language{
			Name:       "Haxe",
			Type:       "programming",
			Color:      "#df7900",
			Extensions: []string{".hx", ".hxsl"},
			TmScope:    "source.haxe.2",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Hy": &Language{
			Name:       "Hy",
			Type:       "programming",
			Color:      "#7790B2",
			Aliases:    []string{"hylang"},
			Extensions: []string{".hy"},
			TmScope:    "source.hy",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"HyPhy": &Language{
			Name:       "HyPhy",
			Type:       "programming",
			Extensions: []string{".bf"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"IDL": &Language{
			Name:       "IDL",
			Type:       "programming",
			Color:      "#a3522f",
			Extensions: []string{".pro", ".dlm"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"IGOR Pro": &Language{
			Name:       "IGOR Pro",
			Type:       "programming",
			Aliases:    []string{"igor", "igorpro"},
			Extensions: []string{".ipf"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"INI": &Language{
			Name:       "INI",
			Type:       "data",
			Aliases:    []string{"dosini"},
			Extensions: []string{".ini", ".cfg", ".prefs", ".pro", ".properties"},
			TmScope:    "source.ini",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"IRC log": &Language{
			Name:       "IRC log",
			Type:       "data",
			Aliases:    []string{"irc", "irc logs"},
			Extensions: []string{".irclog", ".weechatlog"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Idris": &Language{
			Name:       "Idris",
			Type:       "programming",
			Extensions: []string{".idr", ".lidr"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Inform 7": &Language{
			Name:       "Inform 7",
			Type:       "programming",
			Aliases:    []string{"i7", "inform7"},
			Extensions: []string{".ni", ".i7x"},
			TmScope:    "source.inform7",
			AceMode:    "programming",
			Wrap:       true,
			Searchable: true,
		},
		"Inno Setup": &Language{
			Name:       "Inno Setup",
			Type:       "programming",
			Extensions: []string{".iss"},
			TmScope:    "source.inno",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Io": &Language{
			Name:       "Io",
			Type:       "programming",
			Color:      "#a9188d",
			Extensions: []string{".io"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ioke": &Language{
			Name:         "Ioke",
			Type:         "programming",
			Color:        "#078193",
			Extensions:   []string{".ik"},
			Interpreters: []string{"ioke"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Isabelle": &Language{
			Name:       "Isabelle",
			Type:       "programming",
			Color:      "#FEFE00",
			Extensions: []string{".thy"},
			TmScope:    "source.isabelle.theory",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Isabelle ROOT": &Language{
			Name:       "Isabelle ROOT",
			Type:       "programming",
			Group:      "Isabelle",
			Filenames:  []string{"ROOT"},
			TmScope:    "source.isabelle.root",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"J": &Language{
			Name:       "J",
			Type:       "programming",
			Color:      "#9EEDFF",
			Extensions: []string{".ijs"},
			TmScope:    "source.j",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"JFlex": &Language{
			Name:       "JFlex",
			Type:       "programming",
			Group:      "Lex",
			Color:      "#DBCA00",
			Extensions: []string{".flex", ".jflex"},
			TmScope:    "source.jflex",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"JSON": &Language{
			Name:       "JSON",
			Type:       "data",
			Group:      "JavaScript",
			Extensions: []string{".json", ".geojson", ".lock", ".topojson"},
			Filenames:  []string{".jshintrc", "composer.lock"},
			TmScope:    "source.json",
			AceMode:    "data",
			Wrap:       false,
			Searchable: false,
		},
		"JSON5": &Language{
			Name:       "JSON5",
			Type:       "data",
			Extensions: []string{".json5"},
			TmScope:    "source.js",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"JSONLD": &Language{
			Name:       "JSONLD",
			Type:       "data",
			Group:      "JavaScript",
			Extensions: []string{".jsonld"},
			TmScope:    "source.js",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"JSONiq": &Language{
			Name:       "JSONiq",
			Type:       "programming",
			Color:      "#40d47e",
			Extensions: []string{".jq"},
			TmScope:    "source.jq",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"JSX": &Language{
			Name:       "JSX",
			Type:       "programming",
			Group:      "JavaScript",
			Extensions: []string{".jsx"},
			TmScope:    "source.js.jsx",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Jade": &Language{
			Name:       "Jade",
			Type:       "markup",
			Group:      "HTML",
			Extensions: []string{".jade"},
			TmScope:    "text.jade",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Jasmin": &Language{
			Name:       "Jasmin",
			Type:       "programming",
			Extensions: []string{".j"},
			TmScope:    "source.jasmin",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Java": &Language{
			Name:       "Java",
			Type:       "programming",
			Color:      "#b07219",
			Extensions: []string{".java"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Java Server Pages": &Language{
			Name:       "Java Server Pages",
			Type:       "programming",
			Group:      "Java",
			Aliases:    []string{"jsp"},
			Extensions: []string{".jsp"},
			TmScope:    "text.html.jsp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"JavaScript": &Language{
			Name:         "JavaScript",
			Type:         "programming",
			Color:        "#f1e05a",
			Aliases:      []string{"js", "node"},
			Extensions:   []string{".js", "._js", ".bones", ".es6", ".frag", ".gs", ".jake", ".jsb", ".jscad", ".jsfl", ".jsm", ".jss", ".njs", ".pac", ".sjs", ".ssjs", ".sublime-build", ".sublime-commands", ".sublime-completions", ".sublime-keymap", ".sublime-macro", ".sublime-menu", ".sublime-mousemap", ".sublime-project", ".sublime-settings", ".sublime-theme", ".sublime-workspace", ".sublime_metrics", ".sublime_session", ".xsjs", ".xsjslib"},
			Filenames:    []string{"Jakefile"},
			Interpreters: []string{"node"},
			TmScope:      "source.js",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Julia": &Language{
			Name:       "Julia",
			Type:       "programming",
			Color:      "#a270ba",
			Extensions: []string{".jl"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Jupyter Notebook": &Language{
			Name:       "Jupyter Notebook",
			Type:       "markup",
			Color:      "#DA5B0B",
			Aliases:    []string{"IPython Notebook"},
			Extensions: []string{".ipynb"},
			Filenames:  []string{"Notebook"},
			TmScope:    "source.json",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"KRL": &Language{
			Name:       "KRL",
			Type:       "programming",
			Color:      "#28431f",
			Extensions: []string{".krl"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"KiCad": &Language{
			Name:       "KiCad",
			Type:       "programming",
			Extensions: []string{".sch", ".brd", ".kicad_pcb"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Kit": &Language{
			Name:       "Kit",
			Type:       "markup",
			Extensions: []string{".kit"},
			TmScope:    "text.html.basic",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Kotlin": &Language{
			Name:       "Kotlin",
			Type:       "programming",
			Color:      "#F18E33",
			Extensions: []string{".kt", ".ktm", ".kts"},
			TmScope:    "source.Kotlin",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LFE": &Language{
			Name:       "LFE",
			Type:       "programming",
			Group:      "Erlang",
			Color:      "#004200",
			Extensions: []string{".lfe"},
			TmScope:    "source.lisp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LLVM": &Language{
			Name:       "LLVM",
			Type:       "programming",
			Color:      "#185619",
			Extensions: []string{".ll"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LOLCODE": &Language{
			Name:       "LOLCODE",
			Type:       "programming",
			Color:      "#cc9900",
			Extensions: []string{".lol"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LSL": &Language{
			Name:         "LSL",
			Type:         "programming",
			Color:        "#3d9970",
			Extensions:   []string{".lsl", ".lslp"},
			Interpreters: []string{"lsl"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"LabVIEW": &Language{
			Name:       "LabVIEW",
			Type:       "programming",
			Extensions: []string{".lvproj"},
			TmScope:    "text.xml",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Lasso": &Language{
			Name:       "Lasso",
			Type:       "programming",
			Color:      "#999999",
			Aliases:    []string{"lassoscript"},
			Extensions: []string{".lasso", ".las", ".lasso8", ".lasso9", ".ldml"},
			TmScope:    "file.lasso",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Latte": &Language{
			Name:       "Latte",
			Type:       "markup",
			Group:      "HTML",
			Color:      "#A8FF97",
			Extensions: []string{".latte"},
			TmScope:    "text.html.smarty",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Lean": &Language{
			Name:       "Lean",
			Type:       "programming",
			Extensions: []string{".lean", ".hlean"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Less": &Language{
			Name:       "Less",
			Type:       "markup",
			Group:      "CSS",
			Color:      "#A1D9A1",
			Extensions: []string{".less"},
			TmScope:    "source.css.less",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Lex": &Language{
			Name:       "Lex",
			Type:       "programming",
			Color:      "#DBCA00",
			Aliases:    []string{"flex"},
			Extensions: []string{".l", ".lex"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LilyPond": &Language{
			Name:       "LilyPond",
			Type:       "programming",
			Extensions: []string{".ly", ".ily"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Limbo": &Language{
			Name:       "Limbo",
			Type:       "programming",
			Extensions: []string{".b", ".m"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Linker Script": &Language{
			Name:       "Linker Script",
			Type:       "data",
			Extensions: []string{".ld", ".lds"},
			Filenames:  []string{"ld.script"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Linux Kernel Module": &Language{
			Name:       "Linux Kernel Module",
			Type:       "data",
			Extensions: []string{".mod"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Liquid": &Language{
			Name:       "Liquid",
			Type:       "markup",
			Extensions: []string{".liquid"},
			TmScope:    "text.html.liquid",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Literate Agda": &Language{
			Name:       "Literate Agda",
			Type:       "programming",
			Group:      "Agda",
			Extensions: []string{".lagda"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Literate CoffeeScript": &Language{
			Name:       "Literate CoffeeScript",
			Type:       "programming",
			Group:      "CoffeeScript",
			Aliases:    []string{"litcoffee"},
			Extensions: []string{".litcoffee"},
			TmScope:    "source.litcoffee",
			AceMode:    "programming",
			Wrap:       true,
			Searchable: true,
		},
		"Literate Haskell": &Language{
			Name:       "Literate Haskell",
			Type:       "programming",
			Group:      "Haskell",
			Aliases:    []string{"lhaskell", "lhs"},
			Extensions: []string{".lhs"},
			TmScope:    "text.tex.latex.haskell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LiveScript": &Language{
			Name:       "LiveScript",
			Type:       "programming",
			Color:      "#499886",
			Aliases:    []string{"live-script", "ls"},
			Extensions: []string{".ls", "._ls"},
			Filenames:  []string{"Slakefile"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Logos": &Language{
			Name:       "Logos",
			Type:       "programming",
			Extensions: []string{".xm", ".x", ".xi"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Logtalk": &Language{
			Name:       "Logtalk",
			Type:       "programming",
			Extensions: []string{".lgt", ".logtalk"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LookML": &Language{
			Name:       "LookML",
			Type:       "programming",
			Color:      "#652B81",
			Extensions: []string{".lookml"},
			TmScope:    "source.yaml",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"LoomScript": &Language{
			Name:       "LoomScript",
			Type:       "programming",
			Extensions: []string{".ls"},
			TmScope:    "source.loomscript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Lua": &Language{
			Name:         "Lua",
			Type:         "programming",
			Color:        "#000080",
			Extensions:   []string{".lua", ".fcgi", ".nse", ".pd_lua", ".rbxs", ".wlua"},
			Interpreters: []string{"lua"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"M": &Language{
			Name:       "M",
			Type:       "programming",
			Aliases:    []string{"mumps"},
			Extensions: []string{".mumps", ".m"},
			TmScope:    "source.lisp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"MAXScript": &Language{
			Name:       "MAXScript",
			Type:       "programming",
			Color:      "#00a6a6",
			Extensions: []string{".ms", ".mcr"},
			TmScope:    "source.maxscript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"MTML": &Language{
			Name:       "MTML",
			Type:       "markup",
			Color:      "#b7e1f4",
			Extensions: []string{".mtml"},
			TmScope:    "text.html.basic",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"MUF": &Language{
			Name:       "MUF",
			Type:       "programming",
			Group:      "Forth",
			Extensions: []string{".muf", ".m"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Makefile": &Language{
			Name:         "Makefile",
			Type:         "programming",
			Color:        "#427819",
			Aliases:      []string{"bsdmake", "make", "mf"},
			Extensions:   []string{".mak", ".d", ".mk"},
			Filenames:    []string{"GNUmakefile", "Kbuild", "Makefile", "Makefile.am", "Makefile.in", "Makefile.inc", "makefile"},
			Interpreters: []string{"make"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Mako": &Language{
			Name:       "Mako",
			Type:       "programming",
			Extensions: []string{".mako", ".mao"},
			TmScope:    "text.html.mako",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Markdown": &Language{
			Name:       "Markdown",
			Type:       "prose",
			Color:      "#083FA1",
			Extensions: []string{".md", ".markdown", ".mkd", ".mkdn", ".mkdown", ".ron"},
			TmScope:    "source.gfm",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Mask": &Language{
			Name:       "Mask",
			Type:       "markup",
			Color:      "#f97732",
			Extensions: []string{".mask"},
			TmScope:    "source.mask",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Mathematica": &Language{
			Name:       "Mathematica",
			Type:       "programming",
			Aliases:    []string{"mma"},
			Extensions: []string{".mathematica", ".cdf", ".m", ".ma", ".mt", ".nb", ".nbp", ".wl", ".wlt"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Matlab": &Language{
			Name:       "Matlab",
			Type:       "programming",
			Color:      "#bb92ac",
			Aliases:    []string{"octave"},
			Extensions: []string{".matlab", ".m"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Maven POM": &Language{
			Name:       "Maven POM",
			Type:       "data",
			Filenames:  []string{"pom.xml"},
			TmScope:    "text.xml.pom",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Max": &Language{
			Name:       "Max",
			Type:       "programming",
			Color:      "#c4a79c",
			Aliases:    []string{"max/msp", "maxmsp"},
			Extensions: []string{".maxpat", ".maxhelp", ".maxproj", ".mxt", ".pat"},
			TmScope:    "source.json",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"MediaWiki": &Language{
			Name:       "MediaWiki",
			Type:       "prose",
			Extensions: []string{".mediawiki", ".wiki"},
			TmScope:    "text.html.mediawiki",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Mercury": &Language{
			Name:         "Mercury",
			Type:         "programming",
			Color:        "#ff2b2b",
			Extensions:   []string{".m", ".moo"},
			Interpreters: []string{"mmi"},
			TmScope:      "source.mercury",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Metal": &Language{
			Name:       "Metal",
			Type:       "programming",
			Color:      "#8f14e9",
			Extensions: []string{".metal"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"MiniD": &Language{
			Name:       "MiniD",
			Type:       "programming",
			Extensions: []string{".minid"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: false,
		},
		"Mirah": &Language{
			Name:       "Mirah",
			Type:       "programming",
			Color:      "#c7a938",
			Extensions: []string{".druby", ".duby", ".mir", ".mirah"},
			TmScope:    "source.ruby",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Modelica": &Language{
			Name:       "Modelica",
			Type:       "programming",
			Extensions: []string{".mo"},
			TmScope:    "source.modelica",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Modula-2": &Language{
			Name:       "Modula-2",
			Type:       "programming",
			Extensions: []string{".mod"},
			TmScope:    "source.modula2",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Module Management System": &Language{
			Name:       "Module Management System",
			Type:       "programming",
			Extensions: []string{".mms", ".mmk"},
			Filenames:  []string{"descrip.mmk", "descrip.mms"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Monkey": &Language{
			Name:       "Monkey",
			Type:       "programming",
			Extensions: []string{".monkey"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Moocode": &Language{
			Name:       "Moocode",
			Type:       "programming",
			Extensions: []string{".moo"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"MoonScript": &Language{
			Name:         "MoonScript",
			Type:         "programming",
			Extensions:   []string{".moon"},
			Interpreters: []string{"moon"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Myghty": &Language{
			Name:       "Myghty",
			Type:       "programming",
			Extensions: []string{".myt"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"NCL": &Language{
			Name:       "NCL",
			Type:       "programming",
			Color:      "#28431f",
			Extensions: []string{".ncl"},
			TmScope:    "source.ncl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"NL": &Language{
			Name:       "NL",
			Type:       "data",
			Extensions: []string{".nl"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"NSIS": &Language{
			Name:       "NSIS",
			Type:       "programming",
			Extensions: []string{".nsi", ".nsh"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Nemerle": &Language{
			Name:       "Nemerle",
			Type:       "programming",
			Color:      "#3d3c6e",
			Extensions: []string{".n"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"NetLinx": &Language{
			Name:       "NetLinx",
			Type:       "programming",
			Color:      "#0aa0ff",
			Extensions: []string{".axs", ".axi"},
			TmScope:    "source.netlinx",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"NetLinx+ERB": &Language{
			Name:       "NetLinx+ERB",
			Type:       "programming",
			Color:      "#747faa",
			Extensions: []string{".axs.erb", ".axi.erb"},
			TmScope:    "source.netlinx.erb",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"NetLogo": &Language{
			Name:       "NetLogo",
			Type:       "programming",
			Color:      "#ff6375",
			Extensions: []string{".nlogo"},
			TmScope:    "source.lisp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"NewLisp": &Language{
			Name:         "NewLisp",
			Type:         "programming",
			Color:        "#87AED7",
			Extensions:   []string{".nl", ".lisp", ".lsp"},
			Interpreters: []string{"newlisp"},
			TmScope:      "source.lisp",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Nginx": &Language{
			Name:       "Nginx",
			Type:       "markup",
			Color:      "#9469E9",
			Aliases:    []string{"nginx configuration file"},
			Extensions: []string{".nginxconf", ".vhost"},
			Filenames:  []string{"nginx.conf"},
			TmScope:    "source.nginx",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Nimrod": &Language{
			Name:       "Nimrod",
			Type:       "programming",
			Color:      "#37775b",
			Extensions: []string{".nim", ".nimrod"},
			TmScope:    "source.nim",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ninja": &Language{
			Name:       "Ninja",
			Type:       "data",
			Extensions: []string{".ninja"},
			TmScope:    "source.ninja",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Nit": &Language{
			Name:       "Nit",
			Type:       "programming",
			Color:      "#009917",
			Extensions: []string{".nit"},
			TmScope:    "source.nit",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Nix": &Language{
			Name:       "Nix",
			Type:       "programming",
			Color:      "#7e7eff",
			Aliases:    []string{"nixos"},
			Extensions: []string{".nix"},
			TmScope:    "source.nix",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Nu": &Language{
			Name:         "Nu",
			Type:         "programming",
			Color:        "#c9df40",
			Aliases:      []string{"nush"},
			Extensions:   []string{".nu"},
			Filenames:    []string{"Nukefile"},
			Interpreters: []string{"nush"},
			TmScope:      "source.scheme",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"NumPy": &Language{
			Name:       "NumPy",
			Type:       "programming",
			Group:      "Python",
			Color:      "#9C8AF9",
			Extensions: []string{".numpy", ".numpyw", ".numsc"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"OCaml": &Language{
			Name:         "OCaml",
			Type:         "programming",
			Color:        "#3be133",
			Extensions:   []string{".ml", ".eliom", ".eliomi", ".ml4", ".mli", ".mll", ".mly"},
			Interpreters: []string{"ocaml", "ocamlrun"},
			TmScope:      "source.ocaml",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"ObjDump": &Language{
			Name:       "ObjDump",
			Type:       "data",
			Extensions: []string{".objdump"},
			TmScope:    "objdump.x86asm",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Objective-C": &Language{
			Name:       "Objective-C",
			Type:       "programming",
			Color:      "#438eff",
			Aliases:    []string{"obj-c", "objc", "objectivec"},
			Extensions: []string{".m", ".h"},
			TmScope:    "source.objc",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Objective-C++": &Language{
			Name:       "Objective-C++",
			Type:       "programming",
			Color:      "#6866fb",
			Aliases:    []string{"obj-c++", "objc++", "objectivec++"},
			Extensions: []string{".mm"},
			TmScope:    "source.objc++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Objective-J": &Language{
			Name:       "Objective-J",
			Type:       "programming",
			Color:      "#ff0c5a",
			Aliases:    []string{"obj-j", "objectivej", "objj"},
			Extensions: []string{".j", ".sj"},
			TmScope:    "source.js.objj",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Omgrofl": &Language{
			Name:       "Omgrofl",
			Type:       "programming",
			Color:      "#cabbff",
			Extensions: []string{".omgrofl"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Opa": &Language{
			Name:       "Opa",
			Type:       "programming",
			Extensions: []string{".opa"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Opal": &Language{
			Name:       "Opal",
			Type:       "programming",
			Color:      "#f7ede0",
			Extensions: []string{".opal"},
			TmScope:    "source.opal",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"OpenCL": &Language{
			Name:       "OpenCL",
			Type:       "programming",
			Group:      "C",
			Extensions: []string{".cl", ".opencl"},
			TmScope:    "source.c",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"OpenEdge ABL": &Language{
			Name:       "OpenEdge ABL",
			Type:       "programming",
			Aliases:    []string{"progress", "openedge", "abl"},
			Extensions: []string{".p", ".cls"},
			TmScope:    "source.abl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"OpenSCAD": &Language{
			Name:       "OpenSCAD",
			Type:       "programming",
			Extensions: []string{".scad"},
			TmScope:    "source.scad",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Org": &Language{
			Name:       "Org",
			Type:       "prose",
			Extensions: []string{".org"},
			TmScope:    "none",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Ox": &Language{
			Name:       "Ox",
			Type:       "programming",
			Extensions: []string{".ox", ".oxh", ".oxo"},
			TmScope:    "source.ox",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Oxygene": &Language{
			Name:       "Oxygene",
			Type:       "programming",
			Color:      "#cdd0e3",
			Extensions: []string{".oxygene"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Oz": &Language{
			Name:       "Oz",
			Type:       "programming",
			Color:      "#fab738",
			Extensions: []string{".oz"},
			TmScope:    "source.oz",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"PAWN": &Language{
			Name:       "PAWN",
			Type:       "programming",
			Color:      "#dbb284",
			Extensions: []string{".pwn"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"PHP": &Language{
			Name:         "PHP",
			Type:         "programming",
			Color:        "#4F5D95",
			Aliases:      []string{"inc"},
			Extensions:   []string{".php", ".aw", ".ctp", ".fcgi", ".inc", ".php3", ".php4", ".php5", ".phps", ".phpt"},
			Filenames:    []string{"Phakefile"},
			Interpreters: []string{"php"},
			TmScope:      "text.html.php",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"PLSQL": &Language{
			Name:       "PLSQL",
			Type:       "programming",
			Color:      "#dad8d8",
			Extensions: []string{".pls", ".pck", ".pkb", ".pks", ".plb", ".plsql", ".sql"},
			TmScope:    "source.plsql.oracle",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"PLpgSQL": &Language{
			Name:       "PLpgSQL",
			Type:       "programming",
			Extensions: []string{".sql"},
			TmScope:    "source.sql",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"POV-Ray SDL": &Language{
			Name:       "POV-Ray SDL",
			Type:       "programming",
			Aliases:    []string{"pov-ray", "povray"},
			Extensions: []string{".pov", ".inc"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Pan": &Language{
			Name:       "Pan",
			Type:       "programming",
			Color:      "#cc0000",
			Extensions: []string{".pan"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Papyrus": &Language{
			Name:       "Papyrus",
			Type:       "programming",
			Color:      "#6600cc",
			Extensions: []string{".psc"},
			TmScope:    "source.papyrus",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Parrot": &Language{
			Name:       "Parrot",
			Type:       "programming",
			Color:      "#f3ca0a",
			Extensions: []string{".parrot"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Parrot Assembly": &Language{
			Name:         "Parrot Assembly",
			Type:         "programming",
			Group:        "Parrot",
			Aliases:      []string{"pasm"},
			Extensions:   []string{".pasm"},
			Interpreters: []string{"parrot"},
			TmScope:      "none",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Parrot Internal Representation": &Language{
			Name:         "Parrot Internal Representation",
			Type:         "programming",
			Group:        "Parrot",
			Aliases:      []string{"pir"},
			Extensions:   []string{".pir"},
			Interpreters: []string{"parrot"},
			TmScope:      "source.parrot.pir",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Pascal": &Language{
			Name:       "Pascal",
			Type:       "programming",
			Color:      "#E3F171",
			Extensions: []string{".pas", ".dfm", ".dpr", ".inc", ".lpr", ".pp"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Perl": &Language{
			Name:         "Perl",
			Type:         "programming",
			Color:        "#0298c3",
			Extensions:   []string{".pl", ".al", ".cgi", ".fcgi", ".perl", ".ph", ".plx", ".pm", ".pod", ".psgi", ".t"},
			Interpreters: []string{"perl"},
			TmScope:      "source.perl",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Perl6": &Language{
			Name:         "Perl6",
			Type:         "programming",
			Color:        "#0000fb",
			Extensions:   []string{".6pl", ".6pm", ".nqp", ".p6", ".p6l", ".p6m", ".pl", ".pl6", ".pm", ".pm6", ".t"},
			Filenames:    []string{"Rexfile"},
			Interpreters: []string{"perl6"},
			TmScope:      "source.perl6fe",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Pickle": &Language{
			Name:       "Pickle",
			Type:       "data",
			Extensions: []string{".pkl"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"PicoLisp": &Language{
			Name:         "PicoLisp",
			Type:         "programming",
			Extensions:   []string{".l"},
			Interpreters: []string{"picolisp", "pil"},
			TmScope:      "source.lisp",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"PigLatin": &Language{
			Name:       "PigLatin",
			Type:       "programming",
			Color:      "#fcd7de",
			Extensions: []string{".pig"},
			TmScope:    "source.pig_latin",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Pike": &Language{
			Name:         "Pike",
			Type:         "programming",
			Color:        "#005390",
			Extensions:   []string{".pike", ".pmod"},
			Interpreters: []string{"pike"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Pod": &Language{
			Name:       "Pod",
			Type:       "prose",
			Extensions: []string{".pod"},
			TmScope:    "none",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"PogoScript": &Language{
			Name:       "PogoScript",
			Type:       "programming",
			Color:      "#d80074",
			Extensions: []string{".pogo"},
			TmScope:    "source.pogoscript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Pony": &Language{
			Name:       "Pony",
			Type:       "programming",
			Extensions: []string{".pony"},
			TmScope:    "source.pony",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"PostScript": &Language{
			Name:       "PostScript",
			Type:       "markup",
			Aliases:    []string{"postscr"},
			Extensions: []string{".ps", ".eps"},
			TmScope:    "source.postscript",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"PowerShell": &Language{
			Name:       "PowerShell",
			Type:       "programming",
			Aliases:    []string{"posh"},
			Extensions: []string{".ps1", ".psd1", ".psm1"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Processing": &Language{
			Name:       "Processing",
			Type:       "programming",
			Color:      "#0096D8",
			Extensions: []string{".pde"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Prolog": &Language{
			Name:         "Prolog",
			Type:         "programming",
			Color:        "#74283c",
			Extensions:   []string{".pl", ".pro", ".prolog", ".yap"},
			Interpreters: []string{"swipl", "yap"},
			TmScope:      "source.prolog",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Propeller Spin": &Language{
			Name:       "Propeller Spin",
			Type:       "programming",
			Color:      "#7fa2a7",
			Extensions: []string{".spin"},
			TmScope:    "source.spin",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Protocol Buffer": &Language{
			Name:       "Protocol Buffer",
			Type:       "markup",
			Aliases:    []string{"protobuf", "Protocol Buffers"},
			Extensions: []string{".proto"},
			TmScope:    "source.protobuf",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Public Key": &Language{
			Name:       "Public Key",
			Type:       "data",
			Extensions: []string{".asc", ".pub"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Puppet": &Language{
			Name:       "Puppet",
			Type:       "programming",
			Color:      "#302B6D",
			Extensions: []string{".pp"},
			Filenames:  []string{"Modulefile"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Pure Data": &Language{
			Name:       "Pure Data",
			Type:       "programming",
			Color:      "#91de79",
			Extensions: []string{".pd"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"PureBasic": &Language{
			Name:       "PureBasic",
			Type:       "programming",
			Color:      "#5a6986",
			Extensions: []string{".pb", ".pbi"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"PureScript": &Language{
			Name:       "PureScript",
			Type:       "programming",
			Color:      "#1D222D",
			Extensions: []string{".purs"},
			TmScope:    "source.purescript",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Python": &Language{
			Name:         "Python",
			Type:         "programming",
			Color:        "#3572A5",
			Aliases:      []string{"rusthon"},
			Extensions:   []string{".py", ".bzl", ".cgi", ".fcgi", ".gyp", ".lmi", ".pyde", ".pyp", ".pyt", ".pyw", ".tac", ".wsgi", ".xpy"},
			Filenames:    []string{"BUILD", "SConscript", "SConstruct", "Snakefile", "wscript"},
			Interpreters: []string{"python", "python2", "python3"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Python traceback": &Language{
			Name:       "Python traceback",
			Type:       "data",
			Group:      "Python",
			Extensions: []string{".pytb"},
			TmScope:    "text.python.traceback",
			AceMode:    "data",
			Wrap:       false,
			Searchable: false,
		},
		"QML": &Language{
			Name:       "QML",
			Type:       "programming",
			Color:      "#44a51c",
			Extensions: []string{".qml", ".qbs"},
			TmScope:    "source.qml",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"QMake": &Language{
			Name:         "QMake",
			Type:         "programming",
			Extensions:   []string{".pro", ".pri"},
			Interpreters: []string{"qmake"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"R": &Language{
			Name:         "R",
			Type:         "programming",
			Color:        "#198CE7",
			Aliases:      []string{"R", "Rscript", "splus"},
			Extensions:   []string{".r", ".rd", ".rsx"},
			Filenames:    []string{".Rprofile"},
			Interpreters: []string{"Rscript"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"RAML": &Language{
			Name:       "RAML",
			Type:       "markup",
			Color:      "#77d9fb",
			Extensions: []string{".raml"},
			TmScope:    "source.yaml",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"RDoc": &Language{
			Name:       "RDoc",
			Type:       "prose",
			Color:      "#8E84BF",
			Extensions: []string{".rdoc"},
			TmScope:    "text.rdoc",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"REALbasic": &Language{
			Name:       "REALbasic",
			Type:       "programming",
			Extensions: []string{".rbbas", ".rbfrm", ".rbmnu", ".rbres", ".rbtbar", ".rbuistate"},
			TmScope:    "source.vbnet",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"RHTML": &Language{
			Name:       "RHTML",
			Type:       "markup",
			Group:      "HTML",
			Aliases:    []string{"html+ruby"},
			Extensions: []string{".rhtml"},
			TmScope:    "text.html.erb",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"RMarkdown": &Language{
			Name:       "RMarkdown",
			Type:       "prose",
			Extensions: []string{".rmd"},
			TmScope:    "source.gfm",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Racket": &Language{
			Name:         "Racket",
			Type:         "programming",
			Color:        "#22228f",
			Extensions:   []string{".rkt", ".rktd", ".rktl", ".scrbl"},
			Interpreters: []string{"racket"},
			TmScope:      "source.racket",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Ragel in Ruby Host": &Language{
			Name:       "Ragel in Ruby Host",
			Type:       "programming",
			Color:      "#9d5200",
			Aliases:    []string{"ragel-rb", "ragel-ruby"},
			Extensions: []string{".rl"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Raw token data": &Language{
			Name:       "Raw token data",
			Type:       "data",
			Aliases:    []string{"raw"},
			Extensions: []string{".raw"},
			TmScope:    "none",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Rebol": &Language{
			Name:       "Rebol",
			Type:       "programming",
			Color:      "#358a5b",
			Extensions: []string{".reb", ".r", ".r2", ".r3", ".rebol"},
			TmScope:    "source.rebol",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Red": &Language{
			Name:       "Red",
			Type:       "programming",
			Color:      "#ee0000",
			Aliases:    []string{"red/system"},
			Extensions: []string{".red", ".reds"},
			TmScope:    "source.red",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Redcode": &Language{
			Name:       "Redcode",
			Type:       "programming",
			Extensions: []string{".cw"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ren'Py": &Language{
			Name:       "Ren'Py",
			Type:       "programming",
			Group:      "Python",
			Color:      "#ff7f7f",
			Aliases:    []string{"renpy"},
			Extensions: []string{".rpy"},
			TmScope:    "source.renpy",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"RenderScript": &Language{
			Name:       "RenderScript",
			Type:       "programming",
			Extensions: []string{".rs", ".rsh"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"RobotFramework": &Language{
			Name:       "RobotFramework",
			Type:       "programming",
			Extensions: []string{".robot"},
			TmScope:    "text.robot",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Rouge": &Language{
			Name:       "Rouge",
			Type:       "programming",
			Color:      "#cc0088",
			Extensions: []string{".rg"},
			TmScope:    "source.clojure",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Ruby": &Language{
			Name:         "Ruby",
			Type:         "programming",
			Color:        "#701516",
			Aliases:      []string{"jruby", "macruby", "rake", "rb", "rbx"},
			Extensions:   []string{".rb", ".builder", ".fcgi", ".gemspec", ".god", ".irbrc", ".jbuilder", ".mspec", ".pluginspec", ".podspec", ".rabl", ".rake", ".rbuild", ".rbw", ".rbx", ".ru", ".ruby", ".thor", ".watchr"},
			Filenames:    []string{".pryrc", "Appraisals", "Berksfile", "Brewfile", "Buildfile", "Deliverfile", "Fastfile", "Gemfile", "Gemfile.lock", "Guardfile", "Jarfile", "Mavenfile", "Podfile", "Puppetfile", "Snapfile", "Thorfile", "Vagrantfile", "buildfile"},
			Interpreters: []string{"ruby", "macruby", "rake", "jruby", "rbx"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Rust": &Language{
			Name:       "Rust",
			Type:       "programming",
			Color:      "#dea584",
			Extensions: []string{".rs", ".rs.in"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"SAS": &Language{
			Name:       "SAS",
			Type:       "programming",
			Color:      "#B34936",
			Extensions: []string{".sas"},
			TmScope:    "source.sas",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"SCSS": &Language{
			Name:       "SCSS",
			Type:       "markup",
			Group:      "CSS",
			Color:      "#CF649A",
			Extensions: []string{".scss"},
			TmScope:    "source.scss",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"SMT": &Language{
			Name:         "SMT",
			Type:         "programming",
			Extensions:   []string{".smt2", ".smt"},
			Interpreters: []string{"boolector", "cvc4", "mathsat5", "opensmt", "smtinterpol", "smt-rat", "stp", "verit", "yices2", "z3"},
			TmScope:      "source.smt",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"SPARQL": &Language{
			Name:       "SPARQL",
			Type:       "data",
			Extensions: []string{".sparql", ".rq"},
			TmScope:    "source.sparql",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"SQF": &Language{
			Name:       "SQF",
			Type:       "programming",
			Color:      "#3F3F3F",
			Extensions: []string{".sqf", ".hqf"},
			TmScope:    "source.sqf",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"SQL": &Language{
			Name:       "SQL",
			Type:       "data",
			Extensions: []string{".sql", ".cql", ".ddl", ".inc", ".prc", ".tab", ".udf", ".viw"},
			TmScope:    "source.sql",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"SQLPL": &Language{
			Name:       "SQLPL",
			Type:       "programming",
			Extensions: []string{".sql", ".db2"},
			TmScope:    "source.sql",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"STON": &Language{
			Name:       "STON",
			Type:       "data",
			Group:      "Smalltalk",
			Extensions: []string{".ston"},
			TmScope:    "source.smalltalk",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"SVG": &Language{
			Name:       "SVG",
			Type:       "data",
			Extensions: []string{".svg"},
			TmScope:    "text.xml",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Sage": &Language{
			Name:       "Sage",
			Type:       "programming",
			Group:      "Python",
			Extensions: []string{".sage", ".sagews"},
			TmScope:    "source.python",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"SaltStack": &Language{
			Name:       "SaltStack",
			Type:       "programming",
			Color:      "#646464",
			Aliases:    []string{"saltstate", "salt"},
			Extensions: []string{".sls"},
			TmScope:    "source.yaml.salt",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Sass": &Language{
			Name:       "Sass",
			Type:       "markup",
			Group:      "CSS",
			Color:      "#CF649A",
			Extensions: []string{".sass"},
			TmScope:    "source.sass",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Scala": &Language{
			Name:         "Scala",
			Type:         "programming",
			Color:        "#DC322F",
			Extensions:   []string{".scala", ".sbt", ".sc"},
			Interpreters: []string{"scala"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Scaml": &Language{
			Name:       "Scaml",
			Type:       "markup",
			Group:      "HTML",
			Extensions: []string{".scaml"},
			TmScope:    "source.scaml",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Scheme": &Language{
			Name:         "Scheme",
			Type:         "programming",
			Color:        "#1e4aec",
			Extensions:   []string{".scm", ".sld", ".sls", ".sps", ".ss"},
			Interpreters: []string{"guile", "bigloo", "chicken"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Scilab": &Language{
			Name:       "Scilab",
			Type:       "programming",
			Extensions: []string{".sci", ".sce", ".tst"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Self": &Language{
			Name:       "Self",
			Type:       "programming",
			Color:      "#0579aa",
			Extensions: []string{".self"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Shell": &Language{
			Name:         "Shell",
			Type:         "programming",
			Color:        "#89e051",
			Aliases:      []string{"sh", "shell-script", "bash", "zsh"},
			Extensions:   []string{".sh", ".bash", ".bats", ".cgi", ".command", ".fcgi", ".ksh", ".sh.in", ".tmux", ".tool", ".zsh"},
			Interpreters: []string{"bash", "rc", "sh", "zsh"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"ShellSession": &Language{
			Name:       "ShellSession",
			Type:       "programming",
			Aliases:    []string{"bash session", "console"},
			Extensions: []string{".sh-session"},
			TmScope:    "text.shell-session",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Shen": &Language{
			Name:       "Shen",
			Type:       "programming",
			Color:      "#120F14",
			Extensions: []string{".shen"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Slash": &Language{
			Name:       "Slash",
			Type:       "programming",
			Color:      "#007eff",
			Extensions: []string{".sl"},
			TmScope:    "text.html.slash",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Slim": &Language{
			Name:       "Slim",
			Type:       "markup",
			Group:      "HTML",
			Color:      "#ff8f77",
			Extensions: []string{".slim"},
			TmScope:    "text.slim",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Smali": &Language{
			Name:       "Smali",
			Type:       "programming",
			Extensions: []string{".smali"},
			TmScope:    "source.smali",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Smalltalk": &Language{
			Name:       "Smalltalk",
			Type:       "programming",
			Color:      "#596706",
			Aliases:    []string{"squeak"},
			Extensions: []string{".st", ".cs"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Smarty": &Language{
			Name:       "Smarty",
			Type:       "programming",
			Extensions: []string{".tpl"},
			TmScope:    "text.html.smarty",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"SourcePawn": &Language{
			Name:       "SourcePawn",
			Type:       "programming",
			Color:      "#5c7611",
			Aliases:    []string{"sourcemod"},
			Extensions: []string{".sp", ".inc", ".sma"},
			TmScope:    "source.sp",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Squirrel": &Language{
			Name:       "Squirrel",
			Type:       "programming",
			Color:      "#800000",
			Extensions: []string{".nut"},
			TmScope:    "source.c++",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Stan": &Language{
			Name:       "Stan",
			Type:       "programming",
			Color:      "#b2011d",
			Extensions: []string{".stan"},
			TmScope:    "source.stan",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Standard ML": &Language{
			Name:       "Standard ML",
			Type:       "programming",
			Color:      "#dc566d",
			Aliases:    []string{"sml"},
			Extensions: []string{".ML", ".fun", ".sig", ".sml"},
			TmScope:    "source.ml",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Stata": &Language{
			Name:       "Stata",
			Type:       "programming",
			Extensions: []string{".do", ".ado", ".doh", ".ihlp", ".mata", ".matah", ".sthlp"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Stylus": &Language{
			Name:       "Stylus",
			Type:       "markup",
			Group:      "CSS",
			Extensions: []string{".styl"},
			TmScope:    "source.stylus",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"SuperCollider": &Language{
			Name:         "SuperCollider",
			Type:         "programming",
			Color:        "#46390b",
			Extensions:   []string{".sc", ".scd"},
			Interpreters: []string{"sclang", "scsynth"},
			TmScope:      "source.supercollider",
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Swift": &Language{
			Name:       "Swift",
			Type:       "programming",
			Color:      "#ffac45",
			Extensions: []string{".swift"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"SystemVerilog": &Language{
			Name:       "SystemVerilog",
			Type:       "programming",
			Color:      "#DAE1C2",
			Extensions: []string{".sv", ".svh", ".vh"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"TOML": &Language{
			Name:       "TOML",
			Type:       "data",
			Extensions: []string{".toml"},
			TmScope:    "source.toml",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"TXL": &Language{
			Name:       "TXL",
			Type:       "programming",
			Extensions: []string{".txl"},
			TmScope:    "source.txl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Tcl": &Language{
			Name:         "Tcl",
			Type:         "programming",
			Color:        "#e4cc98",
			Extensions:   []string{".tcl", ".adp", ".tm"},
			Interpreters: []string{"tclsh", "wish"},
			AceMode:      "programming",
			Wrap:         false,
			Searchable:   true,
		},
		"Tcsh": &Language{
			Name:       "Tcsh",
			Type:       "programming",
			Group:      "Shell",
			Extensions: []string{".tcsh", ".csh"},
			TmScope:    "source.shell",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"TeX": &Language{
			Name:       "TeX",
			Type:       "markup",
			Color:      "#3D6117",
			Aliases:    []string{"latex"},
			Extensions: []string{".tex", ".aux", ".bbx", ".bib", ".cbx", ".cls", ".dtx", ".ins", ".lbx", ".ltx", ".mkii", ".mkiv", ".mkvi", ".sty", ".toc"},
			AceMode:    "markup",
			Wrap:       true,
			Searchable: true,
		},
		"Tea": &Language{
			Name:       "Tea",
			Type:       "markup",
			Extensions: []string{".tea"},
			TmScope:    "source.tea",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Text": &Language{
			Name:       "Text",
			Type:       "prose",
			Aliases:    []string{"fundamental"},
			Extensions: []string{".txt", ".fr", ".ncl"},
			TmScope:    "none",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Textile": &Language{
			Name:       "Textile",
			Type:       "prose",
			Extensions: []string{".textile"},
			TmScope:    "none",
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"Thrift": &Language{
			Name:       "Thrift",
			Type:       "programming",
			Extensions: []string{".thrift"},
			TmScope:    "source.thrift",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Turing": &Language{
			Name:       "Turing",
			Type:       "programming",
			Color:      "#45f715",
			Extensions: []string{".t", ".tu"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Turtle": &Language{
			Name:       "Turtle",
			Type:       "data",
			Extensions: []string{".ttl"},
			TmScope:    "source.turtle",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Twig": &Language{
			Name:       "Twig",
			Type:       "markup",
			Group:      "HTML",
			Extensions: []string{".twig"},
			TmScope:    "text.html.twig",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"TypeScript": &Language{
			Name:       "TypeScript",
			Type:       "programming",
			Color:      "#2b7489",
			Aliases:    []string{"ts"},
			Extensions: []string{".ts", ".tsx"},
			TmScope:    "source.ts",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Unified Parallel C": &Language{
			Name:       "Unified Parallel C",
			Type:       "programming",
			Group:      "C",
			Color:      "#4e3617",
			Extensions: []string{".upc"},
			TmScope:    "source.c",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Unity3D Asset": &Language{
			Name:       "Unity3D Asset",
			Type:       "data",
			Extensions: []string{".anim", ".asset", ".mat", ".meta", ".prefab", ".unity"},
			TmScope:    "source.yaml",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Uno": &Language{
			Name:       "Uno",
			Type:       "programming",
			Extensions: []string{".uno"},
			TmScope:    "source.cs",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"UnrealScript": &Language{
			Name:       "UnrealScript",
			Type:       "programming",
			Color:      "#a54c4d",
			Extensions: []string{".uc"},
			TmScope:    "source.java",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"UrWeb": &Language{
			Name:       "UrWeb",
			Type:       "programming",
			Aliases:    []string{"Ur/Web", "Ur"},
			Extensions: []string{".ur", ".urs"},
			TmScope:    "source.ur",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"VCL": &Language{
			Name:       "VCL",
			Type:       "programming",
			Group:      "Perl",
			Extensions: []string{".vcl"},
			TmScope:    "source.varnish.vcl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"VHDL": &Language{
			Name:       "VHDL",
			Type:       "programming",
			Color:      "#adb2cb",
			Extensions: []string{".vhdl", ".vhd", ".vhf", ".vhi", ".vho", ".vhs", ".vht", ".vhw"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Vala": &Language{
			Name:       "Vala",
			Type:       "programming",
			Color:      "#fbe5cd",
			Extensions: []string{".vala", ".vapi"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Verilog": &Language{
			Name:       "Verilog",
			Type:       "programming",
			Color:      "#b2b7f8",
			Extensions: []string{".v", ".veo"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"VimL": &Language{
			Name:       "VimL",
			Type:       "programming",
			Color:      "#199f4b",
			Aliases:    []string{"vim", "nvim"},
			Extensions: []string{".vim"},
			Filenames:  []string{".nvimrc", ".vimrc", "_vimrc", "gvimrc", "nvimrc", "vimrc"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Visual Basic": &Language{
			Name:       "Visual Basic",
			Type:       "programming",
			Color:      "#945db7",
			Aliases:    []string{"vb.net", "vbnet"},
			Extensions: []string{".vb", ".bas", ".cls", ".frm", ".frx", ".vba", ".vbhtml", ".vbs"},
			TmScope:    "source.vbnet",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Volt": &Language{
			Name:       "Volt",
			Type:       "programming",
			Color:      "#1F1F1F",
			Extensions: []string{".volt"},
			TmScope:    "source.d",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Vue": &Language{
			Name:       "Vue",
			Type:       "markup",
			Color:      "#2c3e50",
			Extensions: []string{".vue"},
			TmScope:    "text.html.vue",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"Web Ontology Language": &Language{
			Name:       "Web Ontology Language",
			Type:       "markup",
			Color:      "#9cc9dd",
			Extensions: []string{".owl"},
			TmScope:    "text.xml",
			AceMode:    "markup",
			Wrap:       false,
			Searchable: true,
		},
		"WebIDL": &Language{
			Name:       "WebIDL",
			Type:       "programming",
			Extensions: []string{".webidl"},
			TmScope:    "source.webidl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"X10": &Language{
			Name:       "X10",
			Type:       "programming",
			Color:      "#4B6BEF",
			Aliases:    []string{"xten"},
			Extensions: []string{".x10"},
			TmScope:    "source.x10",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"XC": &Language{
			Name:       "XC",
			Type:       "programming",
			Color:      "#99DA07",
			Extensions: []string{".xc"},
			TmScope:    "source.xc",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"XML": &Language{
			Name:       "XML",
			Type:       "data",
			Aliases:    []string{"rss", "xsd", "wsdl"},
			Extensions: []string{".xml", ".ant", ".axml", ".ccxml", ".clixml", ".cproject", ".csl", ".csproj", ".ct", ".dita", ".ditamap", ".ditaval", ".dll.config", ".filters", ".fsproj", ".fxml", ".glade", ".gml", ".grxml", ".iml", ".ivy", ".jelly", ".jsproj", ".kml", ".launch", ".mdpolicy", ".mm", ".mod", ".mxml", ".nproj", ".nuspec", ".odd", ".osm", ".plist", ".pluginspec", ".ps1xml", ".psc1", ".pt", ".rdf", ".rss", ".scxml", ".srdf", ".storyboard", ".stTheme", ".sublime-snippet", ".targets", ".tmCommand", ".tml", ".tmLanguage", ".tmPreferences", ".tmSnippet", ".tmTheme", ".ts", ".tsx", ".ui", ".urdf", ".ux", ".vbproj", ".vcxproj", ".vxml", ".wsdl", ".wsf", ".wxi", ".wxl", ".wxs", ".x3d", ".xacro", ".xaml", ".xib", ".xlf", ".xliff", ".xmi", ".xml.dist", ".xproj", ".xsd", ".xul", ".zcml"},
			Filenames:  []string{".classpath", ".project", "Settings.StyleCop", "Web.Debug.config", "Web.Release.config", "Web.config", "packages.config"},
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"XPages": &Language{
			Name:       "XPages",
			Type:       "programming",
			Extensions: []string{".xsp-config", ".xsp.metadata"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"XProc": &Language{
			Name:       "XProc",
			Type:       "programming",
			Extensions: []string{".xpl", ".xproc"},
			TmScope:    "text.xml",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"XQuery": &Language{
			Name:       "XQuery",
			Type:       "programming",
			Color:      "#5232e7",
			Extensions: []string{".xquery", ".xq", ".xql", ".xqm", ".xqy"},
			TmScope:    "source.xq",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"XS": &Language{
			Name:       "XS",
			Type:       "programming",
			Extensions: []string{".xs"},
			TmScope:    "source.c",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"XSLT": &Language{
			Name:       "XSLT",
			Type:       "programming",
			Color:      "#EB8CEB",
			Aliases:    []string{"xsl"},
			Extensions: []string{".xslt", ".xsl"},
			TmScope:    "text.xml.xsl",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Xojo": &Language{
			Name:       "Xojo",
			Type:       "programming",
			Extensions: []string{".xojo_code", ".xojo_menu", ".xojo_report", ".xojo_script", ".xojo_toolbar", ".xojo_window"},
			TmScope:    "source.vbnet",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Xtend": &Language{
			Name:       "Xtend",
			Type:       "programming",
			Extensions: []string{".xtend"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"YAML": &Language{
			Name:       "YAML",
			Type:       "data",
			Aliases:    []string{"yml"},
			Extensions: []string{".yml", ".reek", ".rviz", ".syntax", ".yaml", ".yaml-tmlanguage"},
			TmScope:    "source.yaml",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"YANG": &Language{
			Name:       "YANG",
			Type:       "data",
			Extensions: []string{".yang"},
			TmScope:    "source.yang",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"Yacc": &Language{
			Name:       "Yacc",
			Type:       "programming",
			Color:      "#4B6C4B",
			Extensions: []string{".y", ".yacc", ".yy"},
			TmScope:    "source.bison",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Zephir": &Language{
			Name:       "Zephir",
			Type:       "programming",
			Color:      "#118f9e",
			Extensions: []string{".zep"},
			TmScope:    "source.php.zephir",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"Zimpl": &Language{
			Name:       "Zimpl",
			Type:       "programming",
			Extensions: []string{".zimpl", ".zmpl", ".zpl"},
			TmScope:    "none",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"desktop": &Language{
			Name:       "desktop",
			Type:       "data",
			Extensions: []string{".desktop", ".desktop.in"},
			TmScope:    "source.desktop",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"eC": &Language{
			Name:       "eC",
			Type:       "programming",
			Color:      "#913960",
			Extensions: []string{".ec", ".eh"},
			TmScope:    "source.c.ec",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"edn": &Language{
			Name:       "edn",
			Type:       "data",
			Extensions: []string{".edn"},
			TmScope:    "source.clojure",
			AceMode:    "data",
			Wrap:       false,
			Searchable: true,
		},
		"fish": &Language{
			Name:       "fish",
			Type:       "programming",
			Group:      "Shell",
			Extensions: []string{".fish"},
			TmScope:    "source.fish",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"mupad": &Language{
			Name:       "mupad",
			Type:       "programming",
			Extensions: []string{".mu"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"nesC": &Language{
			Name:       "nesC",
			Type:       "programming",
			Color:      "#94B0C7",
			Extensions: []string{".nc"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"ooc": &Language{
			Name:       "ooc",
			Type:       "programming",
			Color:      "#b0b77e",
			Extensions: []string{".ooc"},
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"reStructuredText": &Language{
			Name:       "reStructuredText",
			Type:       "prose",
			Color:      "#B3BCBC",
			Aliases:    []string{"rst"},
			Extensions: []string{".rst", ".rest", ".rest.txt", ".rst.txt"},
			AceMode:    "prose",
			Wrap:       true,
			Searchable: true,
		},
		"wisp": &Language{
			Name:       "wisp",
			Type:       "programming",
			Color:      "#7582D1",
			Extensions: []string{".wisp"},
			TmScope:    "source.clojure",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
		"xBase": &Language{
			Name:       "xBase",
			Type:       "programming",
			Color:      "#403a40",
			Aliases:    []string{"advpl", "clipper", "foxpro"},
			Extensions: []string{".prg", ".ch", ".prw"},
			TmScope:    "source.harbour",
			AceMode:    "programming",
			Wrap:       false,
			Searchable: true,
		},
	}
)
